@@ -85,11 +85,11 @@ class Image(Media):
         return digest
 
     # json으로 구성된 메타데이터 전송
-    def upload_file(self, run: Run, key_name: str) -> None:
+    def upload_file(self, run: Run, key_name: str, is_list=False, index=0) -> None:
         # 저장한 파일을 Interface.py의 upoad_file을 호출하여 전송
         digest = self.get_digest()
         root_path = self.get_root_path(run.run_id)
-        path = self.get_path(key_name)
+        path = self.get_path(key_name, is_list, index)
         logger.debug(f"file upload[image] : local_path=[{self.local_path}], root_path=[{root_path}], path=[{path}]")
         interface.upload_file(upload_type="RUN", local_path=self.local_path, root_path=root_path, path=path,
                               run_id=run.run_id, artifact_id=0, last_file_yn="Y", teamName=run.team_name,
