@@ -5,7 +5,7 @@ import pandas as pd
 from assertpy import assert_that
 
 from deepdriver import logger
-from deepdriver.sdk.chart.chart import Chart, TYPE_CONFUSION_MATRIX, TYPE_ROC_CURVE
+from deepdriver.sdk.chart.chart import Chart, TYPE_CONFUSION_MATRIX, TYPE_ROC_CURVE, TYPE_HISTOGRAM
 from deepdriver.sdk.data_types.image import Image
 from deepdriver.sdk.data_types.table import Table
 
@@ -41,7 +41,7 @@ def visualize(obj: Union[Chart, Table, Image]) -> None:
         fig.show()
 
     def visualize_chart_common(obj):
-        # historgram, line, scatter 차트
+        # line, scatter 차트
         plotly_path = "plotly.express"
         plotly_module = importlib.import_module(plotly_path)
         plotly_chart_func = getattr(plotly_module, obj.chart_type)
@@ -54,6 +54,21 @@ def visualize(obj: Union[Chart, Table, Image]) -> None:
         )
         fig.show()
 
+    def visualize_chart_histogram(obj):
+        # historgram
+        plotly_path = "plotly.express"
+        plotly_module = importlib.import_module(plotly_path)
+        plotly_chart_func = getattr(plotly_module, obj.chart_type)
+
+        print(obj.data.dataframe)
+        fig = plotly_chart_func(
+            obj.data.dataframe,
+            x=obj.data_fields["y"],
+            labels=obj.data_fields,
+            title=obj.label_fields["title"],
+        )
+        fig.show()
+
     def visualize_confusion_matrix(obj):
         # dataframe 에서 x, y, z 값 추출
         actual = obj.data.dataframe['Actual']
@@ -144,6 +159,8 @@ def visualize(obj: Union[Chart, Table, Image]) -> None:
             visualize_confusion_matrix(obj)
         elif obj.chart_type == TYPE_ROC_CURVE:
             visualize_roc_curve(obj)
+        elif obj.chart_type == TYPE_HISTOGRAM:
+            visualize_chart_histogram(obj)
         else:
             visualize_chart_common(obj)
     elif isinstance(obj, Table):
